# babylog
## Supported python versions
The babylog Python library is compatible with **Python version 3.8 and above**. It is recommended to use the latest version of Python for best performance and stability. If you are using an older version of Python, you may need to upgrade your Python installation in order to use babylog. You can check your Python version by running the command `python --version` in your command prompt or terminal.

## Installation
Like most python packages, run: 

```bash
pip install babylog
```
